==> neo4j-expressions-5.15.0-sources.jar: org/neo4j/cypher/internal/expressions/functions/ValueType.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.cypher.internal.expressions.functions

import org.neo4j.cypher.internal.expressions.TypeSignature
import org.neo4j.cypher.internal.util.symbols.CTAny
import org.neo4j.cypher.internal.util.symbols.CTString

/**
 * The valueType function is considered breaking if a more specific type is introduced.
 * Due to that, this function should continue to return the less specific type until the next major release.
 * E.g currently returns "FLOAT", if FLOAT32 is introduced it should continue to return "FLOAT" until next major release.
 */
case object ValueType extends Function {
  override def name = "valueType"

  override val signatures = Vector(
    TypeSignature(
      this,
      CTAny,
      CTString,
      "Returns a `STRING` representation of the most precise value type that the given expression evaluates to.",
      Category.SCALAR
    )
  )
}

==> neo4j-expressions-5.26.4-sources.jar: org/neo4j/cypher/internal/expressions/functions/ValueType.scala <==
/*
 * Copyright (c) "Neo4j"
 * Neo4j Sweden AB [https://neo4j.com]
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.neo4j.cypher.internal.expressions.functions

import org.neo4j.cypher.internal.expressions.FunctionTypeSignature
import org.neo4j.cypher.internal.util.symbols.CTAny
import org.neo4j.cypher.internal.util.symbols.CTString

/**
 * The valueType function is considered breaking if a more specific type is introduced.
 * Due to that, this function should continue to return the less specific type until the next major release.
 * E.g currently returns "FLOAT", if FLOAT32 is introduced it should continue to return "FLOAT" until next major release.
 */
case object ValueType extends Function {
  override def name = "valueType"

  override val signatures = Vector(
    FunctionTypeSignature(
      this,
      names = Vector("input"),
      argumentTypes = Vector(CTAny),
      outputType = CTString,
      description =
        "Returns a `STRING` representation of the most precise value type that the given expression evaluates to.",
      category = Category.SCALAR,
      argumentDescriptions = Map("input" -> "A value to return the type of.")
    )
  )
}
